@@ -1,4 +1,3 @@
-/* -*- Mode: csharp; tab-width: 4; c-basic-offset: 4; indent-tabs-mode: t -*- */
 /***************************************************************************
  *  Copyright 2005 Raphaël Slinckx <raphael@slinckx.net> 
  ****************************************************************************/
@@ -26,16 +25,8 @@
 
 /*
  * $Log: ByteBuffer.cs,v $
- * Revision 1.2  2005/08/31 07:59:06  jwillcox
- * 2005-08-31  James Willcox  <snorp@snorp.net>
- *
- *         * add an emacs modeline to all the .cs sources
- *         * src/IpodCore.cs: fix iPod syncing.
- *         * src/PlayerInterface.cs (OnSimpleSearch): fix a null reference that
- *         was causing some crashes.
- *
- * Revision 1.1  2005/08/25 21:03:49  abock
- * New entagged-sharp
+ * Revision 1.5  2005/11/01 23:32:06  abock
+ * Updated entagged tree
  *
  * Revision 1.5  2005/02/13 17:30:15  kikidonk
  * Little fix, peek should not forward the ponter
@@ -61,6 +52,10 @@ namespace Entagged.Audioformats.Util {
 			this.pointer = 0;
 		}
 		
+		public byte[] Data {
+			get { return buf; }
+		}
+		
 		public int Capacity {
 			get { return buf.Length; }
 		}
@@ -101,6 +96,12 @@ namespace Entagged.Audioformats.Util {
 			buf[pointer++] = b;
 		}
 		
+		public void Put(byte[] bytes) {
+			foreach(byte b in bytes) {
+				buf[pointer++] = b;
+			}
+		}
+		
 		public void Rewind() {
 			this.pointer = 0;
 		}
