@@ -292,7 +292,8 @@ namespace Banshee
             playlistView.ButtonReleaseEvent += OnPlaylistViewButtonReleaseEvent;
             playlistView.DragDataReceived += OnPlaylistViewDragDataReceived;
             playlistView.DragDataGet += OnPlaylistViewDragDataGet;
-            playlistView.DragDrop += OnPlaylistViewDragDrop;    
+            playlistView.DragDrop += OnPlaylistViewDragDrop;
+            playlistView.Selection.Changed += OnPlaylistViewSelectionChanged;
                 
             sourceView.SelectLibrary();
                 
@@ -388,10 +389,17 @@ namespace Banshee
           
         private void InstallTrayIcon()
         {
+            try {
+                if(!(bool)Core.GconfClient.Get(GConfKeys.ShowNotificationAreaIcon)) {
+                    return;
+                }
+            } catch(Exception) { }
+                
+            
             try {
                 trayIcon = new NotificationAreaIcon();
-                trayIcon.ClickEvent += new EventHandler(OnTrayClick);
-                //trayIcon.ScrollEvent += new ScrollEventHandler(OnTrayScroll);
+                trayIcon.ClickEvent += OnTrayClick;
+                trayIcon.MouseScrollEvent += OnTrayScroll;
                 
                 trayIcon.PlayItem.Activated += OnButtonPlayPauseClicked;
                 trayIcon.NextItem.Activated += OnButtonNextClicked;
@@ -559,6 +567,12 @@ namespace Banshee
         private void SetInfoLabel(string text)
         {
             LabelInfo.Markup = "<span size=\"small\">" + GLib.Markup.EscapeText(text) + "</span>";
+            
+            if(trayIcon != null && Core.Instance.Player.Playing) {
+                trayIcon.Tooltip = activeTrackInfo.DisplayArtist + " - " 
+                    + activeTrackInfo.DisplayTitle + "\n"
+                    + Catalog.GetString("Position:") + text;
+            }
         }
           
         public void TogglePlaying()
@@ -660,16 +674,16 @@ namespace Banshee
                     }
                     break;
                 case Gdk.Key.Left:
-                    if(args.Event.State == Gdk.ModifierType.ControlMask) {
+                    if((args.Event.State & Gdk.ModifierType.ControlMask) != 0) {
                         Core.Instance.Player.Position -= 10;
                         handled = true;
-                    } else if(args.Event.State == Gdk.ModifierType.ShiftMask) {
+                    } else if((args.Event.State & Gdk.ModifierType.ShiftMask) != 0) {
                         Core.Instance.Player.Position = 0;
                         handled = true;
                     }
                     break;
                 case Gdk.Key.Right:
-                    if(args.Event.State == Gdk.ModifierType.ControlMask) {
+                    if((args.Event.State & Gdk.ModifierType.ControlMask) != 0) {
                         Core.Instance.Player.Position += 10;
                         handled = true;
                     } 
@@ -689,13 +703,37 @@ namespace Banshee
           
         private void OnTrayScroll(object o, ScrollEventArgs args)
         {
+            int tmp_vol = volumeButton.Volume;
+              
             switch(args.Event.Direction) {
                 case Gdk.ScrollDirection.Up:
-                    OnButtonNextClicked(o, args);
+                    if((args.Event.State & Gdk.ModifierType.ControlMask) != 0) {            
+                        tmp_vol += 10;
+                    } else if((args.Event.State & Gdk.ModifierType.ShiftMask) != 0) {
+                        Core.Instance.Player.Position += 10;
+                    } else {
+                        Next();
+                    }
                     break;
                 case Gdk.ScrollDirection.Down:
-                    OnButtonPreviousClicked(o, args);
+                    if((args.Event.State & Gdk.ModifierType.ControlMask) != 0) {            
+                        tmp_vol -= 10;
+                    } else if((args.Event.State & Gdk.ModifierType.ShiftMask) != 0) {
+                        Core.Instance.Player.Position -= 10;
+                    } else {
+                        Previous();
+                    }
                     break;
+                default:
+                    break;
+            }
+            
+            if(tmp_vol != volumeButton.Volume) {
+                // A CLAMP equiv doesn't seem to exist ... doing that manually
+                tmp_vol = Math.Max(0, Math.Min(100, tmp_vol));
+
+                volumeButton.Volume = tmp_vol;
+                OnVolumeScaleChanged(volumeButton.Volume);
             }
         }
         
@@ -1012,6 +1050,24 @@ namespace Banshee
             
         }
         
+        private void OnPlaylistViewSelectionChanged(object o, EventArgs args)
+        {
+            int count = playlistView.Selection.CountSelectedRows();
+            bool have_selection = count > 0;
+            
+            Source source = sourceView.SelectedSource;
+            if(source == null) {
+                return;
+            }
+            
+            gxml["ItemRemoveSongsFileSystem"].Sensitive = !(source is AudioCdSource || source is IpodSource) && have_selection;
+            gxml["ItemRemoveSongs"].Sensitive = !(source is AudioCdSource) && have_selection;
+            gxml["MenuTrackProperties"].Sensitive = have_selection;
+            gxml["ButtonTrackProperties"].Sensitive = have_selection;
+            gxml["ItemBurnCD"].Sensitive = !(source is AudioCdSource) && have_selection;
+            gxml["ButtonBurn"].Sensitive = gxml["ItemBurnCD"].Sensitive;
+        }
+        
         private void OnSourceChanged(object o, EventArgs args)
         {
             if(Core.InMainThread) {
@@ -1027,7 +1083,7 @@ namespace Banshee
             if(source == null) {
                 return;
             }
-                
+
             searchEntry.CancelSearch(false);
                 
             if(source.Type == SourceType.Library) {
@@ -1088,6 +1144,12 @@ namespace Banshee
                 playlistView.Sensitive = false;
             else
                 playlistView.Sensitive = true;
+                
+            OnPlaylistViewSelectionChanged(playlistView.Selection, new EventArgs());
+                
+            gxml["ItemRenamePlaylist"].Sensitive = source is PlaylistSource;
+            gxml["ItemDeletePlaylist"].Sensitive = source is PlaylistSource;
+            gxml["ItemImportCD"].Sensitive = source is AudioCdSource;
         }
         
         private void UpdateIpodDiskUsageBar(IpodSource ipodSource)
@@ -1113,23 +1175,23 @@ namespace Banshee
         
         private void OnIpodDeviceChanged(object o, EventArgs args)
         {
-			Application.Invoke (delegate {
-				IPod.Device device = o as IPod.Device;
-				
-				foreach(object [] obj in (sourceView.Model as ListStore)) {
-					if(obj[0] is IpodSource && (obj[0] as IpodSource).Device == device) {
-						(obj[0] as IpodSource).SetSourceName(device.Name);
-						sourceView.QueueDraw();
-					}
-				}
-				
-				if(playlistModel.Source is IpodSource && (playlistModel.Source as IpodSource).Device == device) {
-					UpdateIpodDiskUsageBar(playlistModel.Source as IpodSource);
-					(gxml["ViewNameLabel"] as Label).Markup = "<b>" 
-						+ GLib.Markup.EscapeText(device.Name) + "</b>";
-					sourceView.QueueDraw();
-				}
-			});
+            Application.Invoke (delegate {
+                IPod.Device device = o as IPod.Device;
+                
+                foreach(object [] obj in (sourceView.Model as ListStore)) {
+                    if(obj[0] is IpodSource && (obj[0] as IpodSource).Device == device) {
+                        (obj[0] as IpodSource).SetSourceName(device.Name);
+                        sourceView.QueueDraw();
+                    }
+                }
+                
+                if(playlistModel.Source is IpodSource && (playlistModel.Source as IpodSource).Device == device) {
+                    UpdateIpodDiskUsageBar(playlistModel.Source as IpodSource);
+                    (gxml["ViewNameLabel"] as Label).Markup = "<b>" 
+                        + GLib.Markup.EscapeText(device.Name) + "</b>";
+                    sourceView.QueueDraw();
+                }
+            });
         }
         
         private void OnIpodCoreDeviceAdded(object o, IpodDeviceArgs args)
@@ -1931,18 +1993,22 @@ namespace Banshee
                     ratingMenu.Append(item);
                 }
             
-                (gxmlPlaylistMenu["ItemAddToPlaylist"] 
-                    as MenuItem).Submenu = plMenu;
-                (gxmlPlaylistMenu["ItemRating"] 
-                    as MenuItem).Submenu = ratingMenu;
+                (gxmlPlaylistMenu["ItemAddToPlaylist"] as MenuItem).Submenu = plMenu;
+                (gxmlPlaylistMenu["ItemRating"] as MenuItem).Submenu = ratingMenu;
             }
         
             menu.ShowAll();
             
-            gxmlPlaylistMenu["ItemAddToPlaylist"].Visible = sensitive;
-            gxmlPlaylistMenu["ItemRating"].Visible = sensitive;
+            gxmlPlaylistMenu["ItemAddToPlaylist"].Visible = sensitive
+                && playlistModel.Source.Type != SourceType.AudioCd;;
+            gxmlPlaylistMenu["ItemRating"].Visible = sensitive
+                && playlistModel.Source.Type != SourceType.AudioCd;
             gxmlPlaylistMenu["ItemSep"].Visible = sensitive;
-            gxmlPlaylistMenu["ItemRemove"].Visible = sensitive;
+            gxmlPlaylistMenu["ItemRemove"].Visible = sensitive
+                && playlistModel.Source.Type != SourceType.AudioCd;
+            gxmlPlaylistMenu["ItemDeleteSongsFileSystem"].Visible = sensitive 
+                && playlistModel.Source.Type != SourceType.Ipod 
+                && playlistModel.Source.Type != SourceType.AudioCd;
             gxmlPlaylistMenu["ItemProperties"].Visible = sensitive;
             
             menu.Popup(null, null, null, 0, time);
@@ -2104,6 +2170,16 @@ namespace Banshee
                 playlistView.Selection.SelectPath(path);
         }
         
+        private void OnItemImportCDActivate(object o, EventArgs args)
+        {
+            OnButtonRipClicked(o, args);
+        }
+        
+        private void OnItemBurnCDActivate(object o, EventArgs args)
+        {
+            OnButtonBurnClicked(o, args);
+        }
+        
         private void OnButtonBurnClicked(object o, EventArgs args)
         {
             if(playlistView.Selection.CountSelectedRows() <= 0) {
